@@ -259,13 +259,6 @@ struct msnetmon_header
 typedef struct msnetmon_header msntm_t;
 #define MSNETMON_SIZE (sizeof(msntm_t))
 /*===========================================================================*/
-struct fcs_frame
-{
- uint32_t	fcs;
-};
-typedef struct fcs_frame fcs_t;
-#define	FCS_SIZE (sizeof(fcs_t))
-/*===========================================================================*/
 struct qos_frame
 {
  uint8_t	control;
@@ -936,11 +929,11 @@ typedef struct chap_frame chap_t;
 struct tacacsp_frame
 {
  uint8_t	version;
-#define TACACSP_VERSION 0xc0
+#define TACACSP_VERSION	0xc0
  uint8_t	type;
-#define TACACS_AUTHENTICATION 1
-#define TACACS2_AUTHENTICATION 2
-#define TACACS3_AUTHENTICATION 3
+#define TACACSP_AUTHEN	1
+#define TACACSP_AUTHOR	2
+#define TACACSP_ACCT	3
  uint8_t	sequencenr;
  uint8_t	flags;
  uint32_t	sessionid;
